PyBEL-CX Documentation
======================
.. automodule:: pybel_cx

Command Line Interface Usage
----------------------------
.. automodule:: pybel_cx.cli

Programmatic Usage
------------------

CX Conversion
~~~~~~~~~~~~~
.. automodule:: pybel_cx.cx

.. autofunction:: pybel_cx.to_cx
.. autofunction:: pybel_cx.to_cx_file
.. autofunction:: pybel_cx.to_cx_jsons
.. autofunction:: pybel_cx.from_cx
.. autofunction:: pybel_cx.from_cx_file
.. autofunction:: pybel_cx.from_cx_jsons

NDEx Client
~~~~~~~~~~~
.. automodule:: pybel_cx.ndex_utils

.. autofunction:: pybel_cx.to_ndex
.. autofunction:: pybel_cx.from_ndex

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
